@@ -96,7 +96,9 @@ struct system_info_t {
     hsa_endianness_t endianness;
     hsa_machine_model_t machine_model;
     bool mwaitx_enabled;
+    bool xnack_enabled;
     bool dmabuf_support;
+    bool vmm_support;
 };
 
 // This structure holds agent information acquired through hsa info related
@@ -307,11 +309,22 @@ static hsa_status_t AcquireSystemInfo(system_info_t *sys_info) {
   err = hsa_system_get_info(HSA_AMD_SYSTEM_INFO_MWAITX_ENABLED,
                                                      &sys_info->mwaitx_enabled);
   RET_IF_HSA_ERR(err);
+
   // Get DMABuf support
   err = hsa_system_get_info(HSA_AMD_SYSTEM_INFO_DMABUF_SUPPORTED,
                                                      &sys_info->dmabuf_support);
   RET_IF_HSA_ERR(err);
 
+  // Get Xnack Enabled
+  err = hsa_system_get_info(HSA_AMD_SYSTEM_INFO_XNACK_ENABLED,
+                                                     &sys_info->xnack_enabled);
+  RET_IF_HSA_ERR(err);
+
+  // Get VMM supported
+  err = hsa_system_get_info(HSA_AMD_SYSTEM_INFO_VIRTUAL_MEM_API_SUPPORTED,
+                                                     &sys_info->vmm_support);
+  RET_IF_HSA_ERR(err);
+
   return err;
 }
 
@@ -343,9 +356,15 @@ static void DisplaySystemInfo(system_info_t const *sys_info) {
   printLabel("Mwaitx:");
   printf("%s\n", sys_info->mwaitx_enabled ? "ENABLED" : "DISABLED");
 
+  printLabel("XNACK enabled:");
+  printf("%s\n", sys_info->xnack_enabled ? "YES" : "NO");
+
   printLabel("DMAbuf Support:");
   printf("%s\n", sys_info->dmabuf_support ? "YES" : "NO");
 
+  printLabel("VMM Support:");
+  printf("%s\n", sys_info->vmm_support ? "YES" : "NO");
+
   printf("\n");
 }
 
@@ -1177,9 +1196,14 @@ int CheckInitialState(void) {
       return -1;
     }
   } else {
-    printf("%sROCk module is NOT loaded, possibly no GPU devices%s\n",
-                                                          COL_RED, COL_RESET);
-    return -1;
+    int module_dir;
+    module_dir = open("/sys/module/amdgpu", O_DIRECTORY);
+    if (module_dir < 0) {
+      printf("%sROCk module is NOT loaded, possibly no GPU devices%s\n",
+                                                            COL_RED, COL_RESET);
+      return -1;
+    }
+    close(module_dir);
   }
 
   // Check if user belongs to the group for /dev/kfd (e.g. "video" or
